loris_log.myException API documentation

# loris_log.myException

This library own customized exception.

class InvalidFTPHostNameException(builtins.Exception):

Custom exception for the invalid FTP hostname.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidFTPPortNumberException(builtins.Exception):

Custom exception for the invalid FTP port number.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidFTPUserNameException(builtins.Exception):

Custom exceptionf or the invalid FTP username.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidFTPPasswordException(builtins.Exception):

Custom exception for the invalid FTP password.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidMessageException(builtins.Exception):

Custom Exception for the invalid message.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidRoleSecretException(builtins.Exception):

Custom exception for the invalid role secret.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class EmptyParameterException(builtins.Exception):

Custom exception for the empty parameter.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidRoleAccessKeyException(builtins.Exception):

Custom exception for the invalid role access key.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class NoneValueException(builtins.Exception):

Custom exception for the non value.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidAttributeException(builtins.Exception):

Custom exception for attribute error.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class InvalidRegionNameException(builtins.Exception):

Custom exception for invalid region name.

Args:

    Exception (string): Invalid region name.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class FTPConnectionFailedException(builtins.Exception):

Custom exception for FTP Connection Failure.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class FTPFileCreationException(builtins.Exception):

Custom exception for file or folder creation failure.

Args:

    Exception (string): The error message.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args